Module network

Module network 

Tools for creating a Network.

This module provides the Network struct, which is used to construct MeshAnalysis and NodalAnalysis instances. A Network is essentially a wrapper around a UnGraph<usize, Excitation> which makes sure the network represented by the graph is suitable for these network analysis methods. Furthermore, this module also contains the BuildError struct, which covers the different reasons why a graph might not be a valid Network. See their respective docstrings for further information.

Structs

EdgeListEdge
An edge where the nodes are defined implicitly via the other edges using them.
Network
A network which is valid for performing mesh and nodal analysis.
NodeEdge
An edge where the node indices are specified explictly.

Enums

BuildError
An error returned from a failed attempt of creating a Network from a graph.
Type
An enum representing the different physical quantities within the Network.